@@ -67,7 +67,7 @@ $target %dowhat readsweeps $max_processes $computype $calcprocedure %specularrat
 toil genstar solvestar integratebox filterbox__ clean
 );
 
-$VERSION = '0.161';
+$VERSION = '0.163';
 $ABSTRACT = 'Sim::OPT is an optimization and parametric exploration program oriented to problem decomposition. It can be used with simulation programs receiving text files as input and emitting text files as output. It allows a free mix of sequential and parallel block coordinate searches.';
 
 #################################################################################
@@ -795,10 +795,10 @@ sub integratebox
 		my @elts = @{ $eltref };
 		my $target = $elts[0]; #say $tee "IN INTEGRATEBOX Target $target" ;
 		my %righttarg = %{ extractcase( $target, \%carrier, $file, \@blockelts, $mypath ) }; #say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
-		my $righttarget = $righttarg{cleanto}; say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
+		my $righttarget = $righttarg{cleanto}; #say $tee "IN INTEGRATEBOX \$righttarget $righttarget" ;
 		my $origin = $elts[3]; #say $tee "IN INTEGRATEBOX \$origin $origin" ;
 		my %rightorig = %{ extractcase( $origin, \%carrier, $file, \@blockelts, $mypath ) }; #say $tee "IN INTEGRATEBOX \$rightorigin $rightorigin";
-		my $rightorigin = $rightorig{cleanto}; say $tee "IN INTEGRATEBOX \$rightorigin $rightorigin" ;
+		my $rightorigin = $rightorig{cleanto}; #say $tee "IN INTEGRATEBOX \$rightorigin $rightorigin" ;
 		push ( @newbox, [ $righttarget, $elts[1], $elts[2], $rightorigin, $elts[4] ] );
 	} #say $tee "IN INTEGRATEBOX \@newbox " . dump( @newbox ) ;
 	return ( \@newbox );
@@ -1162,19 +1162,19 @@ sub takewinning
 sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 {
 	my %d = %{ $_[0] };
-	my $countcase = $d{countcase}; say $tee "IN callblock ( \$countcase) " . dump($countcase);
-	my $countblock = $d{countblock}; say $tee "IN callblock ( \$countblock) " . dump($countblock);
-	my @sweeps = @{ $d{sweeps} }; say $tee "IN callblock \@sweeps " . dump(@sweeps);
+	my $countcase = $d{countcase}; #say $tee "IN callblock ( \$countcase) " . dump($countcase);
+	my $countblock = $d{countblock}; #say $tee "IN callblock ( \$countblock) " . dump($countblock);
+	my @sweeps = @{ $d{sweeps} }; #say $tee "IN callblock \@sweeps " . dump(@sweeps);
 	my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee"IN callblock \@sourcesweeps " . dump(@sourcesweeps);
 	my @miditers = @{ $d{miditers} };
 	@miditers = Sim::OPT::washn( @miditers ); #say $tee "IN callblock \@miditers " . dump( @miditers );
-	my @winneritems = @{ $d{winneritems} }; say $tee "IN callblock \@winneritems " . dump( @winneritems );
+	my @winneritems = @{ $d{winneritems} }; #say $tee "IN callblock \@winneritems " . dump( @winneritems );
 	my %dirfiles = %{ $d{dirfiles} }; #say $tee "IN callblock \%dirfiles " . dump( %dirfiles );
 	my %datastruc = %{ $d{datastruc} };
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN callblock \%dowhat" . dump( %dowhat );
 	my @varnumbers = @{ $d{varnumbers} };
-	my $instn = $d{instn}; say $tee "IN callblock \$instn" . dump( $instn );
-	my %inst = %{ $d{inst} }; say $tee "IN callblock \%inst " . dump( \%inst );
+	my $instn = $d{instn}; #say $tee "IN callblock \$instn" . dump( $instn );
+	my %inst = %{ $d{inst} }; #say $tee "IN callblock \%inst " . dump( \%inst );
 	@varnumbers = Sim::OPT::washn( @varnumbers ); #say $tee"IN callblock ( \@varnumbers) " . dump( @varnumbers );
 
 
@@ -1183,9 +1183,9 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
     exit(say $tee "#END RUN.");
   }
 
-	my @blockelts = @{ getblockelts( \@sweeps, $countcase, $countblock ) }; say $tee "IN callblock \@blockelts " . dump( @blockelts );
+	my @blockelts = @{ getblockelts( \@sweeps, $countcase, $countblock ) }; #say $tee "IN callblock \@blockelts " . dump( @blockelts );
 
-	my @sourceblockelts = @{ getblockelts( \@sourcesweeps, $countcase, $countblock ) }; say $tee "IN callblock \@sourceblockelts " . dump( @sourceblockelts );
+	my @sourceblockelts = @{ getblockelts( \@sourcesweeps, $countcase, $countblock ) }; #say $tee "IN callblock \@sourceblockelts " . dump( @sourceblockelts );
 
 
 	my $entryname;
@@ -1223,8 +1223,8 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 		$dirfiles{starsign} = "no";
 		$dirfiles{stardivisions} = "";
 	}
-	say $tee "IN callblock 3 \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
-	say $tee "IN callblock 3 \$dirfiles{stardivisions} " . dump( $dirfiles{stardivisions} );
+	#say $tee "IN callblock 3 \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	#say $tee "IN callblock 3 \$dirfiles{stardivisions} " . dump( $dirfiles{stardivisions} );
 
 	my @blocks = getblocks( \@sweeps, $countcase );
 
@@ -1238,24 +1238,24 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 
 	#my %intermids = getcase( \@miditers, $countcase ); say $tee "IN callblock \%intermids" . dump( \%intermids ); # UNUSED. CUT,
 	#say $tee "IN callblock \$toitem" . dump( \$toitem ); ### DDD
-	my %carrier = %{ takewinning( $toitem ) }; say $tee "FROM TAKEWINNING IN callblock \%carrier " . dump( \%carrier ); ### DDD
+	my %carrier = %{ takewinning( $toitem ) }; #say $tee "FROM TAKEWINNING IN callblock \%carrier " . dump( \%carrier ); ### DDD
 
 
-	say $tee "IN callblock  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	#say $tee "IN callblock  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 	my @tempvarnumbers;
 	if ( $dirfiles{starsign} eq "yes" )
 	{
 		my @newvarnumbers = @{ stararrange( \@sweeps, \@blockelts, \@varnumbers, $countcase, $countblock, $file ) }; #say $tee "IN2 callblock \@newvarnumbers " . dump( @newvarnumbers );
-		$dirfiles{varnumbershold} = dclone( \@varnumbers ); say $tee "IN2 BEFORE callblock  \$dirfiles{varnumbershold} " . dump( $dirfiles{varnumbershold} );
+		$dirfiles{varnumbershold} = dclone( \@varnumbers ); #say $tee "IN2 BEFORE callblock  \$dirfiles{varnumbershold} " . dump( $dirfiles{varnumbershold} );
 		@varnumbers = @{ dclone( \@newvarnumbers ) };
 		@varnumbers = Sim::OPT::washn( @varnumbers ); #say $tee "IN2 AFTER callblock dcloned \@varnumbers " . dump( @varnumbers );
 
 		%dirfiles = %{ solvestar( { dirfiles => \%dirfiles, dowhat => \%dowhat, varnumbers => \@varnumbers, blockelts => \@blockelts, carrier => \%carrier } ) };
 
-		my @newmiditers = @{ $dirfiles{starpositions} }; say $tee "IN2 callblock \@newmiditers " . dump( @newmiditers );
+		my @newmiditers = @{ $dirfiles{starpositions} }; #say $tee "IN2 callblock \@newmiditers " . dump( @newmiditers );
 		# IT CORRECTS THE PART OF @miditers OUTSIDE THE BLOCKS
 
-		$dirfiles{miditershold} = dclone( \@miditers ); say $tee "IN2 BEFORE callblock  \$dirfiles{miditershold} " . dump( $dirfiles{miditershold} );
+		$dirfiles{miditershold} = dclone( \@miditers ); #say $tee "IN2 BEFORE callblock  \$dirfiles{miditershold} " . dump( $dirfiles{miditershold} );
 
 		#sub checkmids
 		#{
@@ -1282,14 +1282,14 @@ sub callblock # IT CALLS THE SEARCH ON BLOCKS.
 		#
 		#@newmiditers = @{ checkmids( \@newmiditers, $dirfiles{miditershold} ) }; #say $tee "IN2 callblock POST-PROCESSED \@newmiditers " . dump( @newmiditers );
 
-		@miditers = @{ dclone( \@newmiditers ) }; say $tee "IN2 AFTER callblock dcloned \@miditers " . dump( @miditers );
+		@miditers = @{ dclone( \@newmiditers ) }; #say $tee "IN2 AFTER callblock dcloned \@miditers " . dump( @miditers );
 	  #@miditers = Sim::OPT::washn( @miditers ); say $tee "IN2 AFTER callblock dcloned \@miditers " . dump( @miditers );
 		#say $tee "IN2 callblock  \$dirfiles{starpositions} " . dump( $dirfiles{starpositions} );
 	}
 
 
-	my %mids = getcase( \@miditers, $countcase ); say $tee "IN callblock \%mids " . dump( \%mids );
-	my %varnums = getcase( \@varnumbers, $countcase ); say $tee "IN callblock \%varnums " . dump( \%varnums );
+	my %mids = getcase( \@miditers, $countcase ); #say $tee "IN callblock \%mids " . dump( \%mids );
+	my %varnums = getcase( \@varnumbers, $countcase ); #say $tee "IN callblock \%varnums " . dump( \%varnums );
 
   ###########################################################
 
@@ -1332,7 +1332,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
   my $countblock = $d{countblock}; #say $tee "IN DEFFILES \$countblock : " . dump( $countblock );
 	my @sweeps = @{ $d{sweeps} }; #say $tee "IN DEFFILES \@sweeps : " . dump( @sweeps );
 	my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "IN DEFFILES \@sourcesweeps : " . dump( @sourcesweeps );
-	my @miditers = @{ $d{miditers} }; say $tee "IN DEFFILES \@miditers : " . dump( @miditers );
+	my @miditers = @{ $d{miditers} }; #say $tee "IN DEFFILES \@miditers : " . dump( @miditers );
 	my @winneritems = @{ $d{winneritems} }; #say $tee "\@winneritems : " . dump( @winneritems );
 	my %dirfiles = %{ $d{dirfiles} }; #say $tee "IN deffiles \%dirfiles " . dump( %dirfiles );
 	#say $tee "IN DEFFILES \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
@@ -1345,17 +1345,17 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	my @blocks = @{ $d{blocks} }; #say $tee "IN DEFFILES \@blocks : " . dump( @blocks );
 	my $toitem = $d{toitem}; #say $tee "IN12 DEFFILES12 \$toitem : " . dump( $toitem );
 	my $from = $d{from}; #say $tee "IN DEFFILES \$from " . dump( $from );
-	my %varnums = %{ $d{varnums} }; say $tee "IN DEFFILES \%varnums " . dump( \%varnums );
-	my %mids = %{ $d{mids} }; say $tee "IN DEFFILES \%mids " . dump( \%mids );
-	my %carrier = %{ $d{carrier} }; say $tee "IN DEFFILES \%carrier " . dump( \%carrier );
+	my %varnums = %{ $d{varnums} }; #say $tee "IN DEFFILES \%varnums " . dump( \%varnums );
+	my %mids = %{ $d{mids} }; #say $tee "IN DEFFILES \%mids " . dump( \%mids );
+	my %carrier = %{ $d{carrier} }; #say $tee "IN DEFFILES \%carrier " . dump( \%carrier );
 	my $instn = $d{instn};
 	my %inst = %{ $d{inst} };
 
-	say $tee "IN IN DEFFILES  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	#say $tee "IN IN DEFFILES  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 	my $file = $dowhat{file}; #say $tee "IN DEFFILES \$file " . dump( $file );
 	my $mypath = $dowhat{mypath};
 
-	my $starstring = tellstring( \%mids, $file ); say $tee "IN2 DEFFILES1 \$starstring " . dump( $starstring );
+	my $starstring = tellstring( \%mids, $file ); #say $tee "IN2 DEFFILES1 \$starstring " . dump( $starstring );
 	$dirfiles{starstring} = $starstring; # FOR THE OUTTER STAR SEARCH
 
 	my $rootitem = "$file" . "_"; #say $tee "IN DEFFILES \$rootitem : " . dump( $rootitem );
@@ -1429,21 +1429,21 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	}
 	else
 	{
-		say $tee "IN DEFFFILES RIGHT \$dirfiles{starsign} : " . dump( $dirfiles{starsign} );
+		#say $tee "IN DEFFFILES RIGHT \$dirfiles{starsign} : " . dump( $dirfiles{starsign} );
 		@bux = @{ toil( \@blockelts, \%varnums, \@basket, "", $mypath, $file ) };
-	} say $tee "IN DEFFILES2 \@bux: " . dump( @bux );
+	} #say $tee "IN DEFFILES2 \@bux: " . dump( @bux );
 	#say $tee "IN DEFFILES2 \$countblock : " . dump( $countblock );
 	#say $tee "IN DEFFILES \@blockelts : " . dump( @blockelts );
 
 	#############my $flattened_r = flattenbox( \@bux ); 	say $tee "IN DEFFILES2 \$flattened_r: " . dump( $flattened_r );
-	say $tee "In DEFFILES5 \%mids!: " . dump ( %mids );
+	#say $tee "In DEFFILES5 \%mids!: " . dump ( %mids );
 	my ( @finalbox );
 	if ( $dirfiles{starsign} eq "yes" )
 	{
 		my @bag;
 		foreach my $midsurrs_r ( @miditers )
 		{
-			say $tee "MIDITERS FOR MIDSURRS!: " . dump ( @miditers );
+			#say $tee "MIDITERS FOR MIDSURRS!: " . dump ( @miditers );
 			my %midsurrs = %{ $midsurrs_r }; #say $tee "IN DEFFILES \%midsurrs" . dump( \%midsurrs );
 	 		@bag = uniq( @{ integratebox( \@bux, \%midsurrs, $file, \@blockelts, $mypath, \%inst ) } );
 			push( @finalbox, @bag );
@@ -1451,7 +1451,7 @@ sub deffiles # IT DEFINED THE FILES TO BE PROCESSED
 	}
 	else
 	{
-		say $tee "IN DEFFILES RIGHT AFTER " ;
+		#say $tee "IN DEFFILES RIGHT AFTER " ;
 		my @bark = @{ flattenbox( \@bux ) };
 		@finalbox = uniq( @{ integratebox( \@bark, \%carrier, $file, \@blockelts, $mypath, \%inst ) } );
 	}
@@ -1488,8 +1488,8 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN SETLAUNCH \%dowhat" . dump( %dowhat );
 	my $toitem = $d{toitem} ; #say $tee "IN12 SETLAUNCH \$toitem : " . dump( $toitem );
 	my $from = $d{from}; #say $tee "IN12 SETLAUNCH \$from : " . dump( $from );
-	my $instn = $d{instn}; say $tee "IN12 SETLAUNCH \$instn : " . dump( $instn );
-	my %inst = %{ $d{inst} }; say $tee "IN12 SETLAUNCH \%inst : " . dump( \%inst );
+	my $instn = $d{instn}; #say $tee "IN12 SETLAUNCH \$instn : " . dump( $instn );
+	my %inst = %{ $d{inst} }; #say $tee "IN12 SETLAUNCH \%inst : " . dump( \%inst );
 
 	#sub cleaninst
 	#{
@@ -1531,15 +1531,15 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 
 	my ( @instances );
 	my %starters = %{ extractcase( "", \%carrier, $file, \@blockelts, $mypath, "" ) };
-	$dirfiles{starter} = $starters{cleanto}; say $tee "IN SETLAUNCH \$dirfiles{starter}" . dump( $dirfiles{starter} );
+	$dirfiles{starter} = $starters{cleanto}; #say $tee "IN SETLAUNCH \$dirfiles{starter}" . dump( $dirfiles{starter} );
 
 	my $count = 0;
 	foreach my $elt ( @basket )
 	{
 
 		my $newpars = $$elt[0];
-		my $countvar = $$elt[1]; say $tee "IN SETLAUNCH \$countvar! " . dump( $countvar );
-		my $countstep = $$elt[2]; say $tee "IN SETLAUNCH \$countstep! " . dump( $countstep );
+		my $countvar = $$elt[1]; #say $tee "IN SETLAUNCH \$countvar! " . dump( $countvar );
+		my $countstep = $$elt[2]; #say $tee "IN SETLAUNCH \$countstep! " . dump( $countstep );
 		my $oldpars = $$elt[3];
 		my %to = %{ extractcase( $newpars, \%carrier, $file, \@blockelts, $mypath, $instn ) };
 		#say $tee "IN SETLAUNCH \%to" . dump( \%to );
@@ -1556,7 +1556,7 @@ sub setlaunch # IT SETS THE DATA FOR THE SEARCH ON THE ACTIVE BLOCK.
 			my $origin = $orig{cleanto};
 			#say $tee "IN SETLAUNCH \$origin" . dump( \$origin ) . "\n\n";
 			my $c = $$elt[4];
-			say $tee "INSTANCE!: $instn";
+			#say $tee "INSTANCE!: $instn";
 			push ( @instances,
 			{
 				countcase => $countcase, countblock => $countblock,
@@ -1584,27 +1584,27 @@ sub exe
 	my %dirfiles = %{ $dat{dirfiles} }; #say $tee "IN EXE \%dirfiles " . dump( %dfromirfiles );
 
 	my %d = %{ $instances[0] }; #say $tee "IN EXE \%d!!! " . dump( \%d );
-	my $countcase = $d{countcase}; say $tee "IN EXE \$countcase " . dump( $countcase );
-	my $countblock = $d{countblock}; say $tee "IN EXE \$countblock " . dump( $countblock );
-	my @varnumbers = @{ $d{varnumbers} }; say $tee "IN EXE \@varnumbers " . dump( @varnumbers );
-	my @miditers = $d{miditers}; say $tee "IN EXE \@miditers " . dump( @miditers );
-	my @sweeps = @{ $d{sweeps} }; say $tee "IN EXE \@sweeps " . dump( @sweeps );
-	my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "IN EXE \@sourcesweeps " . dump( @sourcesweeps );
-	my @winneritems =  @{ $d{winneritems} }; say $tee "IN EXE \@winneritems " . dump( @winneritems );
+	my $countcase = $d{countcase}; #say $tee "IN EXE \$countcase " . dump( $countcase );
+	my $countblock = $d{countblock}; #say $tee "IN EXE \$countblock " . dump( $countblock );
+	my @varnumbers = @{ $d{varnumbers} }; #say $tee "IN EXE \@varnumbers " . dump( @varnumbers );
+	my @miditers = $d{miditers}; #say $tee "IN EXE \@miditers " . dump( @miditers );
+	my @sweeps = @{ $d{sweeps} }; #say $tee "IN EXE \@sweeps " . dump( @sweeps );
+	my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "IN EXE \@sourcesweeps " . dump( @sourcesweeps );
+	my @winneritems =  @{ $d{winneritems} }; #say $tee "IN EXE \@winneritems " . dump( @winneritems );
 
 	my %datastruc = %{ $d{datastruc} }; #say $tee "IN EXE \%datastruc " . dump( %datastruc );
 	my %dowhat = %{ $d{dowhat} }; #say $tee "IN EXE \%dowhat " . dump( %dowhat );
 	my $toitem = $d{toitem}; #say $tee "IN12 EXE \%toitem : " . dump( \%toitem );
 	my $from = $d{from}; #say $tee "IN12 EXE \%from : " . dump( %from );
-	my %to = %{ $d{to} }; say $tee "IN12 EXE \%to : " . dump( %to );
-	my $countvar = $d{countvar}; say $tee "IN12 EXE \$countvar : " . dump( $countvar );
-	my $countstep = $d{countstep}; say $tee "IN12 EXE \$countstep : " . dump( $countstep );
+	my %to = %{ $d{to} }; #say $tee "IN12 EXE \%to : " . dump( %to );
+	my $countvar = $d{countvar}; #say $tee "IN12 EXE \$countvar : " . dump( $countvar );
+	my $countstep = $d{countstep}; #say $tee "IN12 EXE \$countstep : " . dump( $countstep );
 	my $instn = $d{instn};
-	say $tee "IN EXE  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
+	#say $tee "IN EXE  \$dirfiles{starsign} " . dump( $dirfiles{starsign} );
 	my %inst = %{ $d{inst} };
 
-	my $precomputed = $dowhat{precomputed}; say $tee "IN EXE \$precomputed " . dump( $precomputed ); #NEW
-  my @takecolumns = @{ $dowhat{takecolumns} }; say $tee "IN EXE \@takecolumns " . dump( @takecolumns ); #NEW
+	my $precomputed = $dowhat{precomputed}; #say $tee "IN EXE \$precomputed " . dump( $precomputed ); #NEW
+  my @takecolumns = @{ $dowhat{takecolumns} }; #say $tee "IN EXE \@takecolumns " . dump( @takecolumns ); #NEW
 	my ( @simcases, @simstruct );
 	say $tee "#Performing a search on case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
 
@@ -1682,8 +1682,8 @@ sub genstar
 {
 	my ( $dowhat_ref, $varnumbers_ref, $carrier_ref, $blockelts_ref ) = @_;
 	my %dowhat = %{ $dowhat_ref };
-	my %carrier = %{ $carrier_ref }; say $tee "IN GENSTAR1 \%carrier: " . dump( %carrier );
-	my @blockelts = @{ $blockelts_ref }; say $tee "IN GENSTAR1 \@blockelts: " . dump( @blockelts );
+	my %carrier = %{ $carrier_ref }; #say $tee "IN GENSTAR1 \%carrier: " . dump( %carrier );
+	my @blockelts = @{ $blockelts_ref }; #say $tee "IN GENSTAR1 \@blockelts: " . dump( @blockelts );
 	#say $tee "IN GENSTAR1 \$dowhat{starpositions}: " . dump( $dowhat{starpositions} );
 
 	my @varnumbers = @{ $varnumbers_ref };
@@ -1707,7 +1707,7 @@ sub genstar
 		}
 		push( @starpositions, @genpoints );
 	}
-	say $tee "IN genstar STARPOSITIONS BEFORE: " . dump( @starpositions );
+	#say $tee "IN genstar STARPOSITIONS BEFORE: " . dump( @starpositions );
 
 	my @bag;
 	if ( scalar( @blockelts > 0) )
@@ -1726,7 +1726,7 @@ sub genstar
 		}
 		@starpositions = @bag;
 	}
-	say $tee "IN genstar STARPOSITIONS AFTER: " . dump( @starpositions );
+	#say $tee "IN genstar STARPOSITIONS AFTER: " . dump( @starpositions );
 
 	return( \@starpositions );
 }
@@ -1982,7 +1982,7 @@ sub opt
 		my %datastruc;
 
 		my @winneritems = populatewinners( \@rootnames, $countcase, $countblock );
-		say $tee "PRE CALLCASE \@winneritems: " . dump( @winneritems );
+		#say $tee "PRE CALLCASE \@winneritems: " . dump( @winneritems );
 
 		my $count = 0;
 		my @arr;
@@ -2003,7 +2003,7 @@ sub opt
 			{
 				$dowhat{starpositions} = genstar( \%dowhat, \@varnumbers, $miditers[$countcase] );
 			}
-			say $tee "OUTSTARMODE AFTER \$dowhat{starpositions}: " . dump( \@{ $dowhat{starpositions} } );
+			#say $tee "OUTSTARMODE AFTER \$dowhat{starpositions}: " . dump( \@{ $dowhat{starpositions} } );
 
 			$dowhat{starnumber} = scalar( @{ $dowhat{starpositions} } ); #say $tee "AFTER \$dowhat{starnumber}: " . dump( $dowhat{starnumber} );
 
@@ -2014,9 +2014,9 @@ sub opt
 				$dowhat{randominit} => "no"; # to randomize the init levels specified in @miditers.
 				$dowhat{randomdirs} => "no"; # to randomize the directions of descent.
 
-				my @sweeps = @{ starsweep( \@varnumbers, \@sweeps ) }; say $tee "AFTER0 \@sweeps: " . dump( @sweeps );
+				my @sweeps = @{ starsweep( \@varnumbers, \@sweeps ) }; #say $tee "AFTER0 \@sweeps: " . dump( @sweeps );
 
-				my $number = scalar( @varnumbers ); say $tee "AFTER0 \$number: " . dump( $number );
+				my $number = scalar( @varnumbers ); #say $tee "AFTER0 \$number: " . dump( $number );
 
 				my ( @addition, @addition2, @addition3, @sweepaddition );
 				my $cn = 0;
@@ -2037,7 +2037,7 @@ sub opt
 				my @bag; #say $tee "AFTER0 \@miditers: " . dump( @miditers );
 				my @miditers = @miditers[1 ... $#miditers]; #say $tee "AFTER1 \@miditers: " . dump( @miditers );
 				push( @bag, @{ $dowhat{starpositions} }, @miditers );
-				my @miditers = @bag; say $tee "AFTER3 \@miditers: " . dump( @miditers );
+				my @miditers = @bag; #say $tee "AFTER3 \@miditers: " . dump( @miditers );
 
 				$countstring = 1;
 
