@@ -101,9 +101,9 @@ sub newretrieve
 
   my %dt = %{ $_[0] };
   my %d = %{ $dt{instance} };
-  my %dirfiles = %{ $dt{dirfiles} }; say $tee "# in Newretrieve \%dirfiles " . dump( %dirfiles );
-  my $resfile = $dt{resfile}; say $tee "# in Newretrieve \$resfile $resfile ";
-  my $flfile = $dt{flfile}; say $tee "# in Newretrieve \$flfile $flfile ";
+  my %dirfiles = %{ $dt{dirfiles} }; #say $tee "# in Newretrieve \%dirfiles " . dump( %dirfiles );
+  my $resfile = $dt{resfile}; #say $tee "# in Newretrieve \$resfile $resfile ";
+  my $flfile = $dt{flfile}; #say $tee "# in Newretrieve \$flfile $flfile ";
 
   my @simcases = @{ $dirfiles{simcases} }; ######
   my @simstruct = @{ $dirfiles{simstruct} }; ######
@@ -129,7 +129,7 @@ sub newretrieve
   my $descendlist = $dirfiles{descendlist};
   my $descendblock = $dirfiles{descendblock};
 
-  my $countinstance = $d{instn}; say $tee "# in Newretrieve \$countinstance $countinstance ";
+  my $countinstance = $d{instn}; #say $tee "# in Newretrieve \$countinstance $countinstance ";
 
   my $countcase = $d{countcase}; #say $tee "IN RETRIEVE \$countcase " . dump( $countcase );
   my $countblock = $d{countblock}; #say $tee "IN RETRIEVE \$countblock " . dump( $countblock );
@@ -586,15 +586,15 @@ $printthis
         {
           #say $tee "\$tooltype eq esp-r: yes.";
 
-          my $retfile = $datarep{retfile}; say $tee "IN NEWRETRIEVE \$retfile $retfile";
-          my $reporttitle = $datarep{reporttitle}; say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
-          my $themereport = $datarep{themereport}; say $tee "IN NEWRETRIEVE \$themereport $themereport";
-          my $semaphorego1 = $datarep{semaphorego1}; say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
-          my $semaphorego2 = $datarep{semaphorego2}; say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
-          my $semaphorestop1 = $datarep{semaphorestop1}; say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
-          my $semaphorestop2 = $datarep{semaphorestop2}; say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
-          my $textpattern = $datarep{textpattern}; say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
-          my $afterlines = $datarep{afterlines}; say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
+          my $retfile = $datarep{retfile}; #say $tee "IN NEWRETRIEVE \$retfile $retfile";
+          my $reporttitle = $datarep{reporttitle}; #say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
+          my $themereport = $datarep{themereport}; #say $tee "IN NEWRETRIEVE \$themereport $themereport";
+          my $semaphorego1 = $datarep{semaphorego1}; #say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
+          my $semaphorego2 = $datarep{semaphorego2}; #say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
+          my $semaphorestop1 = $datarep{semaphorestop1}; #say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
+          my $semaphorestop2 = $datarep{semaphorestop2}; #say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
+          my $textpattern = $datarep{textpattern}; #say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
+          my $afterlines = $datarep{afterlines}; #say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
 
 
 
@@ -604,14 +604,14 @@ $printthis
           my $counttheme = 0;
           foreach my $retrievedatum ( @{ $retrievedata{$counttool} } )
           {
-            say $tee " IN NEWRETRIEVE: \$retrievedatum: " . dump( $retrievedatum ) ;
+            #say $tee " IN NEWRETRIEVE: \$retrievedatum: " . dump( $retrievedatum ) ;
             my $reportdata_ref_ref = $reportdata{$counttool}->[$counttheme]; say $tee "\$reportdata_ref_ref : " . dump( $reportdata_ref_ref ) ;
             my @retrievedatarefs = @{$retrievedatum}; say $tee "\@retrievedatarefs : ". dump( @retrievedatarefs );
             my $simtitle = $simtitles{$counttool}->[ $counttheme ][0]; say $tee "\$simtitle : $simtitle .";
             my @sims = @{ $simtitles{$counttool}->[ $counttheme ] }[1..4]; say $tee "\@sims : ". dump( @sims );
 
             #my $resfile = $resfiles[ $counttheme ]; ################ TURNING THIS OFF IS PROVISIONAL!!!
-            say $tee "IN NEWRETRIEVE \$resfile : $resfile .";
+            #say $tee "IN NEWRETRIEVE \$resfile : $resfile .";
 
             #if ( not ( eval ( $skipreport ) ) )
             if ( -e $resfile )
@@ -620,12 +620,12 @@ $printthis
               my $countreport = 0;
               foreach my $retrievedataref (@retrievedatarefs)
               {
-                say $tee "IN FOREACH 2 \$retrievedataref : $retrievedataref .";
-                @retrdata = @$retrievedataref; say $tee "\@retrdata : ". dump( @retrdata );
-                my $sim = $sims[$countreport]; say $tee "\$sim : ". dump( $sim );
+                #say $tee "IN FOREACH 2 \$retrievedataref : $retrievedataref .";
+                @retrdata = @$retrievedataref; #say $tee "\@retrdata : ". dump( @retrdata );
+                my $sim = $sims[$countreport]; #say $tee "\$sim : ". dump( $sim );
                 my $targetprov = $sim;
                 $targetprov =~ s/$mypath\///;
-                my $result = "$mypath/" . "$targetprov"; say $tee "\$result : ". dump( $result );
+                my $result = "$mypath/" . "$targetprov"; #say $tee "\$result : ". dump( $result );
 
                 #if ( fileno (RETLIST) )
                 #if (not (-e $retlist ) )
@@ -653,15 +653,15 @@ $printthis
                 #  }
                 #}from
 
-                my $reportdata_ref = $reportdata_ref_ref->[$countreport]; say $tee "IN NEWRETRIEVE \$reportdata_ref : ". dump( $reportdata_ref );
-                @repdata = @$reportdata_ref; say $tee "IN NEWRETRIEVE \@repdata : ". dump( @repdata );
+                my $reportdata_ref = $reportdata_ref_ref->[$countreport]; #say $tee "IN NEWRETRIEVE \$reportdata_ref : ". dump( $reportdata_ref );
+                @repdata = @$reportdata_ref; #say $tee "IN NEWRETRIEVE \@repdata : ". dump( @repdata );
 
 
 
                 my $countitem = 0;
                 foreach my $item ( @repdata )
                 {
-                  say $tee "IN FOREACH 3 \$item : ". dump( $item );
+                  #say $tee "IN FOREACH 3 \$item : ". dump( $item );
                   my %datarep = %$item;  #say $tee "IN FOREACH 3 \%datarep : ". dump( %datarep);
                   my $reporttitle = $datarep{reporttitle};
                   my $themereport = $datarep{themereport};
@@ -674,16 +674,16 @@ $printthis
                   #my $adhoclines = $datarep{adhoclines}; say $tee "\$adhoclines " . dump($adhoclines);
                   my $retfile = "$resfile-$reporttitle-$themereport.grt";
 
-                  say $tee "IN NEWRETRIEVE \@repdata : ". dump( @repdata );
-                  say $tee "IN NEWRETRIEVE \$retfile $retfile";
-                  say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
-                  say $tee "IN NEWRETRIEVE \$themereport $themereport";
-                  say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
-                  say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
-                  say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
-                  say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
-                  say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
-                  say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
+                  #say $tee "IN NEWRETRIEVE \@repdata : ". dump( @repdata );
+                  #say $tee "IN NEWRETRIEVE \$retfile $retfile";
+                  #say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
+                  #say $tee "IN NEWRETRIEVE \$themereport $themereport";
+                  #say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
+                  #say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
+                  #say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
+                  #say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
+                  #say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
+                  #say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
 
                   $retstruct[$countcase][$countblock][ $countinstance ][$counttheme][$countreport][$countitem][$counttool] = $retfile;
                   print RETBLOCK "$retfile\n";
@@ -704,16 +704,16 @@ $printthis
                     #say $tee "\$counttool : ". dump( $counttool );
                     #say $tee "\$countinstance : ". dump( $countinstance );
 
-                    say $tee "IN NEWREPORT \@repdata : ". dump( @repdata );
-                    say $tee "IN NEWRETRIEVE \$retfile $retfile";
-                    say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
-                    say $tee "IN NEWRETRIEVE \$themereport $themereport";
-                    say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
-                    say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
-                    say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
-                    say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
-                    say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
-                    say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
+                    #say $tee "IN NEWREPORT \@repdata : ". dump( @repdata );
+                    #say $tee "IN NEWRETRIEVE \$retfile $retfile";
+                    #say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
+                    #say $tee "IN NEWRETRIEVE \$themereport $themereport";
+                    #say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
+                    #say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
+                    #say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
+                    #say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
+                    #say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
+                    #say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
 
                     push ( @{ $notecases[ $countcase ][ $countblock ][ $counttool ][ $countinstance ] } ,
                       {
@@ -813,29 +813,29 @@ $printthis
 
                 push ( @provbag, $retfile );
 
-                say $tee "IN NEWREPORT \@repdata : ". dump( @repdata );
-                say $tee "IN NEWRETRIEVE \$retfile $retfile";
-                say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
-                say $tee "IN NEWRETRIEVE \$themereport $themereport";
-                say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
-                say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
-                say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
-                say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
-                say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
-                say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
+                #say $tee "IN NEWREPORT \@repdata : ". dump( @repdata );
+                #say $tee "IN NEWRETRIEVE \$retfile $retfile";
+                #say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
+                #say $tee "IN NEWRETRIEVE \$themereport $themereport";
+                #say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
+                #say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
+                #say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
+                #say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
+                #say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
+                #say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
 
                 my $countitem = 0;
                 foreach my $item ( @repdata )
                 {
                   my %datarep = %$item;
-                  my $reporttitle = $datarep{reporttitle}; say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
-                  my $themereport = $datarep{themereport}; say $tee "IN NEWRETRIEVE \$themereport $themereport";
-                  my $semaphorego1 = $datarep{semaphorego1}; say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
-                  my $semaphorego2 = $datarep{semaphorego2}; say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
-                  my $semaphorestop1 = $datarep{semaphorestop1}; say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
-                  my $semaphorestop2 = $datarep{semaphorestop2}; say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
-                  my $textpattern = $datarep{textpattern}; say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
-                  my $afterlines = $datarep{afterlines}; say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
+                  my $reporttitle = $datarep{reporttitle}; #say $tee "IN NEWRETRIEVE \$reporttitle $reporttitle";
+                  my $themereport = $datarep{themereport}; #say $tee "IN NEWRETRIEVE \$themereport $themereport";
+                  my $semaphorego1 = $datarep{semaphorego1}; #say $tee "IN NEWRETRIEVE \$semaphorego1 $semaphorego1";
+                  my $semaphorego2 = $datarep{semaphorego2}; #say $tee "IN NEWRETRIEVE \$semaphorego2 $semaphorego2";
+                  my $semaphorestop1 = $datarep{semaphorestop1}; #say $tee "IN NEWRETRIEVE \$semaphorestop1 $semaphorestop1";
+                  my $semaphorestop2 = $datarep{semaphorestop2}; #say $tee "IN NEWRETRIEVE \$semaphorestop2 $semaphorestop2";
+                  my $textpattern = $datarep{textpattern}; #say $tee "IN NEWRETRIEVE \$textpattern $textpattern";
+                  my $afterlines = $datarep{afterlines}; #say $tee "IN NEWRETRIEVE \$afterlines $afterlines";
 
                   print RETBLOCK "$retfile\n";
 
@@ -982,8 +982,8 @@ sub newreport # This function retrieves the results of interest from the texts f
   my $countvar = $d{countvar}; #say $tee "IN REPORT \$countvar " . dump( $countvar );
   my $countstep = $d{countstep}; #say $tee "IN REPORT \$countstep " . dump( $countstep );
 
-  my %to = %{ $d{to} }; say $tee "IN REPORT \%to " . dump( \%to );
-  my %inst = %{ $d{inst} }; say $tee "IN REPORT \%inst " . dump( \%inst );
+  my %to = %{ $d{to} }; #say $tee "IN REPORT \%to " . dump( \%to );
+  my %inst = %{ $d{inst} }; #say $tee "IN REPORT \%inst " . dump( \%inst );
 
   my $from = $d{from}; #say $tee " IN MORPH \$from $from ";
   my $toitem = $d{toitem}; #say $tee " IN MORPH \$toitem $toitem ";
@@ -1000,7 +1000,7 @@ sub newreport # This function retrieves the results of interest from the texts f
   my $stepsvar = $varnums{$countvar}; ;
 
   my %dowhat = %{ $d{dowhat} }; #say $tee "DOWHAT IN NEWREPORT " . dump( %dowhat );
-  my $resfile = $d{resfile}; say $tee "IN NEWREPORT \$resfile $resfile";
+  my $resfile = $d{resfile}; #say $tee "IN NEWREPORT \$resfile $resfile";
 
 
   my $direction = ${$dowhat{direction}}[$countcase][$countblock]; #NEW
@@ -1231,15 +1231,15 @@ sub newreport # This function retrieves the results of interest from the texts f
         if ( $count == 0 )
         {
           $thing =~ s/$mypath\/// ;
-          $thing =~ /^(\w+__)/ ;  say $tee "IN REPORT!! \$thing BEFORE  $thing";
-          my $head = $1; say $tee "IN REPORT!! \$head  $head";
+          $thing =~ /^(\w+__)/ ;  #say $tee "IN REPORT!! \$thing BEFORE  $thing";
+          my $head = $1; #say $tee "IN REPORT!! \$head  $head";
           my $oldhead = $head;
-          $head = "$mypath/" . $head; say $tee "IN REPORT!! \$head  $head";
+          $head = "$mypath/" . $head; #say $tee "IN REPORT!! \$head  $head";
           my $newhead = $inst{$head};
           if ( $newhead ne "" )
           {
-            $newhead = $newhead . "__"; say $tee "IN REPORT!! \$newhead  $newhead";
-            $thing =~ s/^$oldhead/$newhead/ ; say $tee "IN REPORT!! \$thing AFTER  $thing";
+            $newhead = $newhead . "__"; #say $tee "IN REPORT!! \$newhead  $newhead";
+            $thing =~ s/^$oldhead/$newhead/ ; #say $tee "IN REPORT!! \$thing AFTER  $thing";
           }
           #$thing = $newhead . "__" . $thing ; say $tee "IN REPORT!! \$thing AFTER  $thing";
         }
