@@ -175,7 +175,7 @@ sub sim    # This function launch the simulations in ESP-r
     my @blocks = $dt{blocks};
     my %varnums = $dt{varnums};
     my %mids = $dt{mids};
-    my $countinstance = $dt{instn}; say $tee "IN SIM1 \$countinstance : " . dump( $countinstance );
+    my $countinstance = $dt{instn}; #say $tee "IN SIM1 \$countinstance : " . dump( $countinstance );
 
 
     my $skip = $dowhat{$countvar}{skip}; #########################################
@@ -190,7 +190,7 @@ sub sim    # This function launch the simulations in ESP-r
     my $countdir = 0;
 
     my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } );
-    my $simelt = $to{crypto}; say $tee "IN SIM \$simelt $simelt";
+    my $simelt = $to{crypto}; #say $tee "IN SIM \$simelt $simelt";
 
 
     if ( $dowhat{simulate} eq "y")
@@ -218,8 +218,8 @@ sub sim    # This function launch the simulations in ESP-r
               my $before = $simtitle_ref->[3];
               my $step = $simtitle_ref->[4];
 
-              $resfile = "$simelt-$date_to_sim-$tooltype.res"; say $tee "IN SIM \$resfile $resfile";
-              $flfile = "$simelt-$date_to_sim-$tooltype.fl"; say $tee "IN SIM \$flfile $flfile";
+              $resfile = "$simelt-$date_to_sim-$tooltype.res"; #say $tee "IN SIM \$resfile $resfile";
+              $flfile = "$simelt-$date_to_sim-$tooltype.fl"; #say $tee "IN SIM \$flfile $flfile";
 
               #if ( fileno (SIMLIST) )
               #if (not (-e $simlist ) )
@@ -367,14 +367,7 @@ $printthis
               my $epnewpath;
               $resfile;
 
-              unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
-              {
-                $epnewpath = $to . $epdir . "/" . $epnewfile;
-              }
-              else
-              {
-                $epnewpath = $to . $epdir . "\\" . $epnewfile;
-              }
+              $epnewpath = $to . $epdir . "/" . $epnewfile;
 
               my @simdos = @{ $simtitle_ref };
               my @changes = @simdos[ 12..$#simdos ];
@@ -523,9 +516,9 @@ $printthis
 
     if ( $dowhat{newretrieve} eq "y" )
     {
-      say $tee "INSIM1: countinstance: $countinstance";
-      say $tee "INSIM1: \$resfile: $resfile";
-      say $tee "INSIM1: \$flfile: $flfile";
+      #say $tee "INSIM1: countinstance: $countinstance";
+      #say $tee "INSIM1: \$resfile: $resfile";
+      #say $tee "INSIM1: \$flfile: $flfile";
       my @resultretrieve = Sim::OPT::Report::newretrieve(
       {
         instance => $instance, dirfiles => \%dirfiles,
